==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/V1ContainerStateTerminatedFluent.java <==
package io.kubernetes.client.models;

import java.lang.Integer;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import org.joda.time.DateTime;

public interface V1ContainerStateTerminatedFluent<A extends V1ContainerStateTerminatedFluent<A>> extends Fluent<A>{


    public String getContainerID();
    public A withContainerID(String containerID);
    public Boolean hasContainerID();
    public Integer getExitCode();
    public A withExitCode(Integer exitCode);
    public Boolean hasExitCode();
    public A withNewExitCode(int arg1);
    public A withNewExitCode(String arg1);
    public DateTime getFinishedAt();
    public A withFinishedAt(DateTime finishedAt);
    public Boolean hasFinishedAt();
    public A withNewFinishedAt(int arg0,int arg1,int arg2,int arg3,int arg4);
    public A withNewFinishedAt(long arg0);
    public A withNewFinishedAt(Object arg0);
    public String getMessage();
    public A withMessage(String message);
    public Boolean hasMessage();
    public String getReason();
    public A withReason(String reason);
    public Boolean hasReason();
    public Integer getSignal();
    public A withSignal(Integer signal);
    public Boolean hasSignal();
    public A withNewSignal(int arg1);
    public A withNewSignal(String arg1);
    public DateTime getStartedAt();
    public A withStartedAt(DateTime startedAt);
    public Boolean hasStartedAt();
    public A withNewStartedAt(int arg0,int arg1,int arg2,int arg3,int arg4);
    public A withNewStartedAt(long arg0);
    public A withNewStartedAt(Object arg0);



}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1ContainerStateTerminatedFluent.java <==
package io.kubernetes.client.models;

import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import org.joda.time.DateTime;

public interface V1ContainerStateTerminatedFluent<A extends V1ContainerStateTerminatedFluent<A>> extends Fluent<A>{


    public String getContainerID();
    public A withContainerID(String containerID);
    public Boolean hasContainerID();
    public A withNewContainerID(String arg1);
    public A withNewContainerID(StringBuilder arg1);
    public A withNewContainerID(StringBuffer arg1);
    public Integer getExitCode();
    public A withExitCode(Integer exitCode);
    public Boolean hasExitCode();
    public DateTime getFinishedAt();
    public A withFinishedAt(DateTime finishedAt);
    public Boolean hasFinishedAt();
    public A withNewFinishedAt(int arg0,int arg1,int arg2,int arg3,int arg4);
    public A withNewFinishedAt(Object arg0);
    public A withNewFinishedAt(long arg0);
    public String getMessage();
    public A withMessage(String message);
    public Boolean hasMessage();
    public A withNewMessage(String arg1);
    public A withNewMessage(StringBuilder arg1);
    public A withNewMessage(StringBuffer arg1);
    public String getReason();
    public A withReason(String reason);
    public Boolean hasReason();
    public A withNewReason(String arg1);
    public A withNewReason(StringBuilder arg1);
    public A withNewReason(StringBuffer arg1);
    public Integer getSignal();
    public A withSignal(Integer signal);
    public Boolean hasSignal();
    public DateTime getStartedAt();
    public A withStartedAt(DateTime startedAt);
    public Boolean hasStartedAt();
    public A withNewStartedAt(int arg0,int arg1,int arg2,int arg3,int arg4);
    public A withNewStartedAt(Object arg0);
    public A withNewStartedAt(long arg0);



}
